@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2009 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -160,14 +160,12 @@ avi_extra_toggled_avi (GtkWidget *widget,
   gtk_widget_set_sensitive (GTK_WIDGET (extra->notebook), TRUE);
   if (GTK_IS_NOTEBOOK (extra->notebook))
     {
-      gint i;
       GList *glist;
 
       glist = gtk_container_get_children (GTK_CONTAINER (extra->notebook));
-      for (i = g_list_length (glist) - 1; i >= 0; i--)
-        gtk_widget_set_sensitive (GTK_WIDGET (g_list_nth_data (glist, i)),
-                                                                        TRUE);
-      g_list_free (glist);
+      for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
+        gtk_widget_set_sensitive (GTK_WIDGET (glist->data), TRUE);
     }
 }
 
@@ -186,15 +184,13 @@ avi_extra_toggled_bitmap (GtkWidget *widget,
 #endif /* GTK_CHECK_VERSION(2,2,0) */
   if (extra->video > 1)
     {
-      gint i;
       GList *glist;
 
       gtk_widget_set_sensitive (GTK_WIDGET (extra->notebook), TRUE);
       glist = gtk_container_get_children (GTK_CONTAINER (extra->notebook));
-      for (i = g_list_length (glist) - 1; i >= 0; i--)
-        gtk_widget_set_sensitive (GTK_WIDGET (g_list_nth_data (glist, i)),
-                                                                        FALSE);
-      g_list_free (glist);
+      for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
+        gtk_widget_set_sensitive (GTK_WIDGET (glist->data), FALSE);
     }
   else
     {
@@ -219,15 +215,13 @@ avi_extra_toggled_pixbuf (GtkWidget *widget,
     gtk_widget_set_sensitive (GTK_WIDGET (extra->hbox_png), TRUE);
   if (extra->video > 1)
     {
-      gint i;
       GList *glist;
 
       gtk_widget_set_sensitive (GTK_WIDGET (extra->notebook), TRUE);
       glist = gtk_container_get_children (GTK_CONTAINER (extra->notebook));
-      for (i = g_list_length (glist) - 1; i >= 0; i--)
-        gtk_widget_set_sensitive (GTK_WIDGET (g_list_nth_data (glist, i)),
-                                                                        FALSE);
-      g_list_free (glist);
+      for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
+        gtk_widget_set_sensitive (GTK_WIDGET (glist->data), FALSE);
     }
   else
     {
@@ -247,21 +241,20 @@ avi_extra_toggled_wave (GtkWidget *widget,
   gtk_widget_set_sensitive (GTK_WIDGET (extra->notebook), TRUE);
   if (GTK_IS_NOTEBOOK (extra->notebook))
     {
-      gint i;
       GList *glist;
 
       glist = gtk_container_get_children (GTK_CONTAINER (extra->notebook));
-      for (i = g_list_length (glist) - 1; i >= 0; i--)
+      for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
         {
           GtkWidget *child;
           AviExtraStream *avi_stream;
 
-          child = g_list_nth_data (glist, i);
+          child = glist->data;
           avi_stream = g_object_get_data (G_OBJECT (child), "user_data");
           gtk_widget_set_sensitive (GTK_WIDGET (child),
                     avi_edit_type (avi_stream->avi_edit) == AVI_TYPE_AUDIO);
         }
-      g_list_free (glist);
     }
   else
     {
@@ -320,7 +313,6 @@ avi_extra_changed_video (GtkWidget      *widget,
   GtkTreeIter iter;
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   const gchar *text;
-  gint i;
   GList *glist;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   IcmObject *icm_object = NULL;
@@ -334,19 +326,14 @@ avi_extra_changed_video (GtkWidget      *widget,
   text = gtk_entry_get_text (GTK_ENTRY (widget));
   glist = gtk_container_get_children
                         (GTK_CONTAINER (GTK_COMBO (avi_stream->combo)->list));
-  for (i = g_list_length (glist) - 1; i >= 0; i--)
-    {
-      const gchar *label;
-
-      label = gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
-                                    (GTK_BIN (g_list_nth_data (glist, i)))));
-      if (g_strcmp (label, text) == 0)
-        {
-          icm_object = g_object_get_data
-                        (G_OBJECT (g_list_nth_data (glist, i)), "user_data");
-          break;
-        }
-    }
+  for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
+    if (g_strcmp (gtk_label_get_text
+        (GTK_LABEL (gtk_bin_get_child (GTK_BIN (glist->data)))), text) == 0)
+      {
+        icm_object = g_object_get_data (G_OBJECT (glist->data), "user_data");
+        break;
+      }
   g_list_free (glist);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   g_object_set_data (G_OBJECT (avi_stream->combo), "user_data", icm_object);
@@ -418,7 +405,6 @@ avi_extra_changed_audio (GtkWidget      *widget,
   GtkTreeIter iter;
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   const gchar *text;
-  gint i;
   GList *glist;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   WaveFormatEx *wfx = NULL;
@@ -432,19 +418,14 @@ avi_extra_changed_audio (GtkWidget      *widget,
   text = gtk_entry_get_text (GTK_ENTRY (widget));
   glist = gtk_container_get_children
                         (GTK_CONTAINER (GTK_COMBO (avi_stream->combo)->list));
-  for (i = g_list_length (glist) - 1; i >= 0; i--)
-    {
-      const gchar *label;
-
-      label = gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
-                                    (GTK_BIN (g_list_nth_data (glist, i)))));
-      if (g_strcmp (label, text) == 0)
-        {
-          wfx = g_object_get_data
-                        (G_OBJECT (g_list_nth_data (glist, i)), "user_data");
-          break;
-        }
-    }
+  for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
+    if (g_strcmp (gtk_label_get_text
+        (GTK_LABEL (gtk_bin_get_child (GTK_BIN (glist->data)))), text) == 0)
+      {
+        wfx = g_object_get_data (G_OBJECT (glist->data), "user_data");
+        break;
+      }
   g_list_free (glist);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   g_object_set_data (G_OBJECT (avi_stream->combo), "user_data", wfx);
@@ -512,14 +493,12 @@ static void
 avi_extra_destroy_list_video (GtkWidget *widget,
                               gpointer   user_data)
 {
-  gint i;
   GList *glist;
 
   glist = gtk_container_get_children (GTK_CONTAINER (widget));
-  for (i = g_list_length (glist) - 1; i >= 0; i--)
-    icm_close (g_object_get_data (G_OBJECT (g_list_nth_data (glist, i)),
-                                                                "user_data"));
-  g_list_free (glist);
+  for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
+    icm_close (g_object_get_data (G_OBJECT (glist->data), "user_data"));
 }
 
 
@@ -528,14 +507,12 @@ static void
 avi_extra_destroy_list_audio (GtkWidget *widget,
                               gpointer   user_data)
 {
-  gint i;
   GList *glist;
 
   glist = gtk_container_get_children (GTK_CONTAINER (widget));
-  for (i = g_list_length (glist) - 1; i >= 0; i--)
-    g_free (g_object_get_data (G_OBJECT (g_list_nth_data (glist, i)),
-                                                                "user_data"));
-  g_list_free (glist);
+  for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
+    g_free (g_object_get_data (G_OBJECT (glist->data), "user_data"));
 }
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
 
@@ -553,7 +530,6 @@ avi_extra_changed_pixbuf (GtkWidget *widget,
   GtkTreeIter iter;
 # else /* not GTK_CHECK_VERSION(2,4,0) */
   const gchar *text;
-  gint i;
   GList *glist;
 # endif /* not GTK_CHECK_VERSION(2,4,0) */
   GdkPixbufFormat *format = NULL;
@@ -567,19 +543,14 @@ avi_extra_changed_pixbuf (GtkWidget *widget,
   text = gtk_entry_get_text (GTK_ENTRY (widget));
   glist = gtk_container_get_children
                             (GTK_CONTAINER (GTK_COMBO (extra->combo)->list));
-  for (i = g_list_length (glist) - 1; i >= 0; i--)
-    {
-      const gchar *label;
-
-      label = gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
-                                    (GTK_BIN (g_list_nth_data (glist, i)))));
-      if (g_strcmp (label, text) == 0)
-        {
-          format = g_object_get_data
-                        (G_OBJECT (g_list_nth_data (glist, i)), "user_data");
-          break;
-        }
-    }
+  for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
+    if (g_strcmp (gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
+                                        (GTK_BIN (glist->data)))), text) == 0)
+      {
+        format = g_object_get_data (G_OBJECT (glist->data), "user_data");
+        break;
+      }
   g_list_free (glist);
 # endif /* not GTK_CHECK_VERSION(2,4,0) */
   vbox = gtk_widget_get_parent (gtk_widget_get_parent (extra->combo));
@@ -699,13 +670,9 @@ avi_extra_set_handle (AviExtra  *extra,
   if (!extra)
     return;
   glist = gtk_container_get_children (GTK_CONTAINER (extra));
-  if (glist)
-    {
-      for (i = g_list_length (glist) - 1; i >= 0; i--)
-        gtk_container_remove (GTK_CONTAINER (extra),
-                                    GTK_WIDGET (g_list_nth_data (glist, i)));
-      g_list_free (glist);
-    }
+  for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
+    gtk_container_remove (GTK_CONTAINER (extra), GTK_WIDGET (glist->data));
 #if GTK_CHECK_VERSION(2,2,0)
   if (extra->hbox_ico)
     gtk_widget_destroy (extra->hbox_ico);
@@ -797,7 +764,6 @@ avi_extra_set_handle (AviExtra  *extra,
                             G_CALLBACK (avi_extra_destroy_vbox), avi_stream);
       if (avi_edit_type (avi_edit[i]) == AVI_TYPE_VIDEO)
         { /* ja:ビデオストリーム */
-          gint j;
           GList *glist_object;      /* ja:IcmObjectのリスト */
           GList *glist_name;        /* ja:名前のリスト */
 
@@ -810,13 +776,13 @@ avi_extra_set_handle (AviExtra  *extra,
           glist_object = g_list_append (NULL, NULL);
           glist_name = g_list_append (NULL, _("Uncompress"));
           /* ja:各4文字コードについて */
-          for (j = 0; j < leng_handler; j++)
+          for (glist = g_list_first (glist_handler);
+                                            glist; glist = g_list_next (glist))
             {
               IcmObject *icm_object;
 
               icm_object = icm_open
-                        (GPOINTER_TO_UINT (g_list_nth_data (glist_handler, j)),
-                                                            ICM_MODE_COMPRESS);
+                        (GPOINTER_TO_UINT (glist->data), ICM_MODE_COMPRESS);
               if (!icm_object)
                 continue;
               if (!icm_compress_query (icm_object, avi_edit[i]->bmih))
@@ -850,6 +816,7 @@ avi_extra_set_handle (AviExtra  *extra,
             }
           if (g_list_length (glist_name) > 1)
             {
+              gint j;
 #if GTK_CHECK_VERSION(2,4,0)
               GtkListStore *store;
               GtkCellRenderer *renderer;
@@ -1027,7 +994,6 @@ avi_extra_set_handle (AviExtra  *extra,
         }
       else
         { /* ja:オーディオストリーム */
-          gint j;
           GList *glist_wfx;         /* ja:WaveFormatEx構造体のリスト */
           GList *glist_name;        /* ja:名前のリスト */
 #if GTK_CHECK_VERSION(2,4,0)
@@ -1045,7 +1011,8 @@ avi_extra_set_handle (AviExtra  *extra,
           glist_name = g_list_append (NULL, g_strdup (_("PCM")));
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
           /* ja:各タグについて */
-          for (j = 0; j < leng_tag; j++)
+          for (glist = g_list_first (glist_tag);
+                                            glist; glist = g_list_next (glist))
             {
               gsize leng;
               gchar *name;
@@ -1053,8 +1020,7 @@ avi_extra_set_handle (AviExtra  *extra,
               AcmObject *acm_object;
               WaveFormatEx *wfx;
 
-              acm_object = acm_open ((guint16)GPOINTER_TO_UINT
-                                            (g_list_nth_data (glist_tag, j)));
+              acm_object = acm_open ((guint16)GPOINTER_TO_UINT (glist->data));
               if (!acm_object)
                 continue;
               leng = acm_compress_get_format_size (acm_object,
@@ -1085,6 +1051,7 @@ avi_extra_set_handle (AviExtra  *extra,
             }
           if (g_list_length (glist_name) > 1)
             {
+              gint j;
 #if GTK_CHECK_VERSION(2,4,0)
               GtkListStore *store;
               GtkCellRenderer *renderer;
@@ -1179,11 +1146,10 @@ avi_extra_set_handle (AviExtra  *extra,
                                               g_list_nth_data (glist_name, 0));
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
             }
-          for (j = g_list_length (glist_name) - 1; j >= 0; j--)
 #if GTK_CHECK_VERSION(2,4,0)
-            g_strfreev (g_list_nth_data (glist_name, j));
+          g_list_foreach (glist_name, (GFunc)g_strfreev, NULL);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
-            g_free (g_list_nth_data (glist_name, j));
+          g_list_foreach (glist_name, (GFunc)g_free, NULL);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
           g_list_free (glist_wfx);
           g_list_free (glist_name);
@@ -1270,7 +1236,6 @@ avi_extra_set_handle (AviExtra  *extra,
     {
       GtkWidget *label1, *hbox1;
 #if GTK_CHECK_VERSION(2,2,0)
-      gint j;
       GSList *gslist_formats, *gslist_sorted = NULL;
       GtkWidget *vbox;
 #endif /* GTK_CHECK_VERSION(2,2,0) */
@@ -1303,19 +1268,15 @@ avi_extra_set_handle (AviExtra  *extra,
       gtk_label_set_mnemonic_widget (GTK_LABEL (label1), extra->spin_end);
       /* ja:コンボボックス */
 #if GTK_CHECK_VERSION(2,2,0)
-      gslist_formats = gdk_pixbuf_get_formats ();
-      for (j = 0; j < g_slist_length (gslist_formats); j++)
-        {
-          GdkPixbufFormat *format;
-
-          format = g_slist_nth_data (gslist_formats, j);
-          if (gdk_pixbuf_format_is_writable (format))
-            gslist_sorted = g_slist_insert_sorted (gslist_sorted, format,
+      for (gslist_formats = gdk_pixbuf_get_formats (); gslist_formats;
+        gslist_formats = g_slist_delete_link (gslist_formats, gslist_formats))
+        if (gdk_pixbuf_format_is_writable (gslist_formats->data))
+          gslist_sorted = g_slist_insert_sorted (gslist_sorted,
+                                    gslist_formats->data,
                                     (GCompareFunc)avi_extra_set_handle_sort);
-        }
-      g_slist_free (gslist_formats);
       if (g_slist_length (gslist_sorted) > 0)
         {
+          GSList *gsl;
 # if GTK_CHECK_VERSION(2,4,0)
           GtkCellRenderer *renderer;
           GtkListStore *store;
@@ -1325,7 +1286,7 @@ avi_extra_set_handle (AviExtra  *extra,
           GList *glist = NULL;
 
 # endif /* GTK_CHECK_VERSION(2,2,0) */
-          for (j = 0; j < g_slist_length (gslist_sorted); j++)
+          for (gsl = gslist_sorted; gsl; gsl = g_slist_next (gsl))
             {
               gchar *desc, *name;
               GdkPixbufFormat *format;
@@ -1333,7 +1294,7 @@ avi_extra_set_handle (AviExtra  *extra,
               GtkTreeIter iter;
 # endif /* GTK_CHECK_VERSION(2,4,0) */
 
-              format = g_slist_nth_data (gslist_sorted, j);
+              format = gsl->data;
               desc = gdk_pixbuf_format_get_description (format);
               name = gdk_pixbuf_format_get_name (format);
               if (g_strcmp (name, "ico") == 0)
@@ -1426,7 +1387,7 @@ avi_extra_set_handle (AviExtra  *extra,
                   gtk_widget_set_sensitive
                                     (GTK_WIDGET (extra->spin_ico_y), FALSE);
                   gtk_widget_show_all (extra->hbox_ico);
-                  if (j <= 0)
+                  if (!extra->hbox_current)
                     extra->hbox_current = extra->hbox_ico;
                 }
               else if (g_strcmp (name, "jpeg") == 0)
@@ -1448,7 +1409,7 @@ avi_extra_set_handle (AviExtra  *extra,
                   gtk_widget_set_sensitive
                                         (GTK_WIDGET (extra->spin_jpeg), FALSE);
                   gtk_widget_show_all (GTK_WIDGET (extra->hbox_jpeg));
-                  if (j <= 0)
+                  if (!extra->hbox_current)
                     extra->hbox_current = extra->hbox_jpeg;
                 }
               else if (g_strcmp (name, "png") == 0)
@@ -1477,7 +1438,7 @@ avi_extra_set_handle (AviExtra  *extra,
                   gtk_widget_set_sensitive
                                         (GTK_WIDGET (extra->spin_png), FALSE);
                   gtk_widget_show_all (GTK_WIDGET (extra->hbox_png));
-                  if (j <= 0)
+                  if (!extra->hbox_current)
                     extra->hbox_current = extra->hbox_png;
                 }
 # if GTK_CHECK_VERSION(2,4,0)
@@ -1503,8 +1464,7 @@ avi_extra_set_handle (AviExtra  *extra,
             }
           extra->combo = gtk_combo_new ();
           gtk_combo_set_popdown_strings (GTK_COMBO (extra->combo), glist);
-          for (j = g_list_length (glist) - 1; j >= 0; j--)
-            g_free (g_list_nth_data (glist, j));
+          g_list_foreach (glist, (GFunc)g_free, NULL);
           g_list_free (glist);
           glist = gtk_container_get_children
                             (GTK_CONTAINER (GTK_COMBO (extra->combo)->list));
@@ -1797,7 +1757,6 @@ avi_extra_get_option (AviExtra *extra)
           GtkTreeIter iter;
 # else /* not GTK_CHECK_VERSION(2,4,0) */
           const gchar *text;
-          gint i;
           GList *glist_combo;
 # endif /* not GTK_CHECK_VERSION(2,4,0) */
           GdkPixbufFormat *format = NULL;
@@ -1812,19 +1771,15 @@ avi_extra_get_option (AviExtra *extra)
                                 (GTK_ENTRY (GTK_COMBO (extra->combo)->entry));
           glist_combo = gtk_container_get_children
                             (GTK_CONTAINER (GTK_COMBO (extra->combo)->list));
-          for (i = g_list_length (glist_combo) - 1; i >= 0; i--)
-            {
-              const gchar *label;
-
-              label = gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
-                                (GTK_BIN (g_list_nth_data (glist_combo, i)))));
-              if (g_strcmp (label, text) == 0)
-                {
-                  format = g_object_get_data (G_OBJECT (g_list_nth_data
-                                            (glist_combo, i)), "user_data");
-                  break;
-                }
-            }
+          for (glist_combo = g_list_first (glist_combo); glist_combo;
+                glist_combo = g_list_delete_link (glist_combo, glist_combo))
+            if (g_strcmp (gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
+                                (GTK_BIN (glist_combo->data)))), text) == 0)
+              {
+                format = g_object_get_data (G_OBJECT (glist_combo->data),
+                                                                "user_data");
+                break;
+              }
           g_list_free (glist_combo);
 # endif /* not GTK_CHECK_VERSION(2,4,0) */
           if (format)
