@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2009 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -605,7 +605,7 @@ avi_play_value_changed (GtkWidget *widget,
                         AviPlay   *play)
 {
   avi_play_set_position_internal (play,
-                                    gtk_range_get_value (GTK_RANGE (widget)));
+                            (gint)gtk_range_get_value (GTK_RANGE (widget)));
 }
 
 
