@@ -1,10 +1,10 @@
 /*
     avicore
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,16 +13,13 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #ifndef __GSRFMT_H__
 #define __GSRFMT_H__
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 
 /******************************************************************************
@@ -126,9 +123,7 @@ typedef struct { guint8 dummy[GIE_SIZE]; } GsrIndexEntry;
                         (*(guint32 *)((guint8 *)(gie)+12)=GUINT32_TO_LE(flags))
 
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 
 #endif /* __GSRFMT_H__ */
