@@ -1,10 +1,10 @@
 /*
-    avicore
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    bitmap
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "bitmap.h"
 
@@ -311,7 +310,7 @@ bitmap_make_palette (const gint   count,
         j |= 7;
       rgbquad_set (rgb, i, RGB_BLUE, j);
       j = (ptl[i].green_min + ptl[i].green_max) / 2 * 8;
-      if (j&8)
+      if (j & 8)
         j |= 7;
       rgbquad_set (rgb, i, RGB_GREEN, j);
       j = (ptl[i].red_min + ptl[i].red_max) / 2 * 8;
