@@ -1,10 +1,10 @@
 /*
     orzmdi
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2009 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,18 +13,11 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "orzmdi.h"
 #include "misc/fileio.h"
-
-
-static void orz_mdi_class_init (OrzMdiClass *klass);
-static void orz_mdi_init       (OrzMdi      *mdi);
-
-
-static GtkNotebookClass *parent_class = NULL;
+#include "misc/misc.h"
 
 
 enum
@@ -37,8 +30,6 @@ enum
   SWITCH_WINDOW_SIGNAL,
   LAST_SIGNAL
 };
-
-
 enum
 {
   TARGET_ORZ_MDI_TAB
@@ -107,18 +98,17 @@ static void
 file_add_edit (OrzMdi    *mdi,
                OrzMdiTab *tab0)
 {
-  gint i;
-  GList *glist;
+  GList *gl, *glist;
   OrzMdiTab *tab1;
 
   tab0->same = -2;
   /* ja:ファイル名を調べる */
   glist = gtk_container_get_children (GTK_CONTAINER (mdi));
   /* ja:同名同パスを調べる */
-  for (i = g_list_length (glist) - 1; i >= 0; i--)
+  for (gl = g_list_first (glist); gl; gl = g_list_next (gl))
     {
       tab1 = g_object_get_data (G_OBJECT (gtk_notebook_get_tab_label
-            (GTK_NOTEBOOK (mdi), g_list_nth_data (glist, i))), "user_data");
+                                (GTK_NOTEBOOK (mdi), gl->data)), "user_data");
       if (tab1 && tab0 != tab1 && g_strfilecmp (tab0->file, tab1->file) == 0)
         {
           if (tab1->same < 0)
@@ -137,10 +127,10 @@ file_add_edit (OrzMdi    *mdi,
       /* ja:同名同パスはないとき */
       /* ja:同名異パスを調べる */
       name0 = g_path_get_basename (tab0->file);
-      for (i = g_list_length (glist) - 1; i >= 0; i--)
+      for (gl = g_list_first (glist); gl; gl = g_list_next (gl))
         {
           tab1 = g_object_get_data (G_OBJECT (gtk_notebook_get_tab_label
-            (GTK_NOTEBOOK (mdi), g_list_nth_data (glist, i))), "user_data");
+                                (GTK_NOTEBOOK (mdi), gl->data)), "user_data");
           if (tab1 && tab0 != tab1)
             {
               gchar *name1;
@@ -160,7 +150,7 @@ file_add_edit (OrzMdi    *mdi,
             }
         }
       g_free (name0);
-      if (i >= 0)
+      if (gl)
         tab0->same = -1;
     }
   g_list_free (glist);
@@ -172,18 +162,18 @@ file_remove_edit (OrzMdi      *mdi,
                   OrzMdiTab   *tab0,
                   const gchar *file)
 {
-  gint i, count0 = 0, count1 = 0;
+  gint count0 = 0, count1 = 0;
   gchar *name0, *name1;
-  GList *glist;
+  GList *gl, *glist;
   OrzMdiTab *tab1;
 
   /* ja:ファイル名を調べる */
   glist = gtk_container_get_children (GTK_CONTAINER (mdi));
   name0 = g_path_get_basename (tab0->file);
-  for (i = g_list_length (glist) - 1; i >= 0; i--)
+  for (gl = g_list_first (glist); gl; gl = g_list_next (gl))
     {
       tab1 = g_object_get_data (G_OBJECT (gtk_notebook_get_tab_label
-            (GTK_NOTEBOOK (mdi), g_list_nth_data (glist, i))), "user_data");
+                                (GTK_NOTEBOOK (mdi), gl->data)), "user_data");
       if (tab1 && tab0 != tab1)
         {
           /* ja:同名同パスを調べる */
@@ -203,12 +193,11 @@ file_remove_edit (OrzMdi      *mdi,
       name2 = file ? g_path_get_basename (file) : NULL;
       if (!name2 || g_strfilecmp (name0, name2) != 0)
         /* 名前が変わっているとき */
-        for (i = g_list_length (glist) - 1; i >= 0; i--)
+        for (gl = g_list_first (glist); gl; gl = g_list_next (gl))
           {
             /* ja:同名のファイルを通常表示に変更する */
             tab1 = g_object_get_data (G_OBJECT (gtk_notebook_get_tab_label
-                            (GTK_NOTEBOOK (mdi), g_list_nth_data (glist, i))),
-                                                                "user_data");
+                                (GTK_NOTEBOOK (mdi), gl->data)), "user_data");
             if (tab1 && tab0 != tab1)
               {
                 /* ja:同名を調べる */
@@ -224,18 +213,21 @@ file_remove_edit (OrzMdi      *mdi,
       g_free (name2);
     }
   else if (count0 == 1)/* ja:同名同パスが1つだけある(異パスは複数)とき */
-    for (i = g_list_length (glist) - 1; i >= 0; i--)
-      {
-        /* ja:同名同パスのファイルをフルパスに変更する */
-        tab1 = g_object_get_data (G_OBJECT (gtk_notebook_get_tab_label
-            (GTK_NOTEBOOK (mdi), g_list_nth_data (glist, i))), "user_data");
-        /* ja:同名同パスを調べる */
-        if (tab1 && tab0 != tab1 && g_strfilecmp (tab0->file, tab1->file) == 0)
-          {
-            tab1->same = -1;
-            orz_mdi_label_markup (tab1);
-          }
-      }
+    {
+      for (gl = g_list_first (glist); gl; gl = g_list_next (gl))
+        {
+          /* ja:同名同パスのファイルをフルパスに変更する */
+          tab1 = g_object_get_data (G_OBJECT (gtk_notebook_get_tab_label
+                                (GTK_NOTEBOOK (mdi), gl->data)), "user_data");
+          /* ja:同名同パスを調べる */
+          if (tab1 && tab0 != tab1
+                                && g_strfilecmp (tab0->file, tab1->file) == 0)
+            {
+              tab1->same = -1;
+              orz_mdi_label_markup (tab1);
+            }
+        }
+    }
   g_free (name0);
   g_list_free (glist);
 }
@@ -244,32 +236,7 @@ file_remove_edit (OrzMdi      *mdi,
 /******************************************************************************
 *                                                                             *
 ******************************************************************************/
-GtkType
-orz_mdi_get_type (void)
-{
-  static GType orz_mdi_type = 0;
-
-  if (!orz_mdi_type)
-    {
-      const static GTypeInfo mdi_info =
-      {
-        sizeof (OrzMdiClass),
-        NULL,               /* base_init */
-        NULL,               /* base_finalize */
-        (GClassInitFunc)orz_mdi_class_init,
-        NULL,               /* class_finalize */
-        NULL,               /* class_data */
-        sizeof (OrzMdi),
-        0,              /* n_preallocs */
-        (GInstanceInitFunc)orz_mdi_init,
-      };
-
-      orz_mdi_type = g_type_register_static (GTK_TYPE_NOTEBOOK, "OrzMdi",
-                                                                &mdi_info, 0);
-    }
-
-  return orz_mdi_type;
-}
+G_DEFINE_TYPE (OrzMdi, orz_mdi, GTK_TYPE_NOTEBOOK);
 
 
 /* ja:子ウィジェットが破棄されるとき */
@@ -293,12 +260,9 @@ orz_mdi_remove (GtkContainer *container,
                     gtk_notebook_page_num (GTK_NOTEBOOK (container), widget),
                     tab->page_data);
           file_remove_edit (ORZ_MDI (container), tab, NULL);
-          g_free (tab->file);
-          g_free (tab);
-          g_object_set_data (G_OBJECT (tab_label), "user_data", NULL);
         }
     }
-  ((GtkContainerClass *)parent_class)->remove (container, widget);
+  GTK_CONTAINER_CLASS (orz_mdi_parent_class)->remove (container, widget);
 }
 
 
@@ -309,7 +273,8 @@ orz_mdi_switch_page (GtkNotebook     *notebook,
 {
   GtkWidget *child;
 
-  parent_class->switch_page (notebook, page, page_num);
+  GTK_NOTEBOOK_CLASS (orz_mdi_parent_class)->switch_page
+                                                    (notebook, page, page_num);
   child = gtk_notebook_get_nth_page (notebook, page_num);
   if (child)
     {
@@ -338,11 +303,9 @@ orz_mdi_class_init (OrzMdiClass *klass)
   GtkContainerClass *container_class;
   GtkNotebookClass *notebook_class;
 
-  container_class = (GtkContainerClass *) klass;
-  notebook_class = (GtkNotebookClass *) klass;
-
-  parent_class = g_type_class_peek_parent (klass);
+  container_class = GTK_CONTAINER_CLASS (klass);
   container_class->remove = orz_mdi_remove;
+  notebook_class = GTK_NOTEBOOK_CLASS (klass);
   notebook_class->switch_page = orz_mdi_switch_page;
 
   klass->add_window = NULL;
@@ -455,8 +418,8 @@ orz_mdi_clicked (GtkWidget *widget,
 
 /* ja:子ウィジェットが破棄されるとき */
 static void
-orz_mdi_destroy (GtkWidget *widget,
-                 OrzMdi    *mdi)
+orz_mdi_destroy_child (GtkWidget *widget,
+                       OrzMdi    *mdi)
 {
   GtkWidget *tab_label;
 
@@ -474,14 +437,28 @@ orz_mdi_destroy (GtkWidget *widget,
                          gtk_notebook_page_num (GTK_NOTEBOOK (mdi), widget),
                          tab->page_data);
           file_remove_edit (ORZ_MDI (mdi), tab, NULL);
-          g_free (tab->file);
-          g_free (tab);
-          g_object_set_data (G_OBJECT (tab_label), "user_data", NULL);
         }
     }
 }
 
 
+/* ja:タブが破棄されるとき */
+static void
+orz_mdi_destroy_tab (GtkWidget *widget,
+                     OrzMdi    *mdi)
+{
+  OrzMdiTab *tab;
+
+  tab = g_object_get_data (G_OBJECT (widget), "user_data");
+  if (tab)
+    {
+      g_free (tab->file);
+      g_free (tab);
+      g_object_set_data (G_OBJECT (widget), "user_data", NULL);
+    }
+}
+
+
 /* ja:ドロップされたとき */
 static void
 orz_mdi_tab_drag_begin (GtkWidget      *widget,
@@ -558,8 +535,7 @@ orz_mdi_create_tab_label (OrzMdi         *mdi,
                           gpointer        page_data)
 {
   GdkPixbuf *pixbuf;
-  GtkIconSet *icon_set;
-  GtkWidget *image = NULL, *button, *hbox, *event;
+  GtkWidget *button, *hbox, *event;
   GtkTargetEntry dnd_entries[1] = {{"ORZ_MDI_TAB",
                                     GTK_TARGET_SAME_APP, TARGET_ORZ_MDI_TAB}};
   OrzMdiTab *tab;
@@ -575,108 +551,9 @@ orz_mdi_create_tab_label (OrzMdi         *mdi,
   tab->mdi = mdi;
   tab->child = child;
   file_add_edit (mdi, tab);
-  /* ja:イメージ */
-  icon_set = gtk_icon_factory_lookup_default (GTK_STOCK_CLOSE);
-  if (icon_set)
-    {
-      pixbuf = gtk_icon_set_render_icon (icon_set,
-                                         gtk_widget_get_default_style (),
-                                         GTK_TEXT_DIR_NONE,
-                                         GTK_STATE_NORMAL,
-                                         GTK_ICON_SIZE_MENU,
-                                         NULL, NULL);
-      if (pixbuf)
-        {
-          if (gdk_pixbuf_get_colorspace (pixbuf) == GDK_COLORSPACE_RGB
-                            && gdk_pixbuf_get_n_channels (pixbuf) == 4
-                            && gdk_pixbuf_get_has_alpha (pixbuf)
-                            && gdk_pixbuf_get_bits_per_sample (pixbuf) == 8)
-            {
-              int width, height, rowstride;
-              gint x, y, left, top, right, bottom;
-              guchar *pixels;
-
-              pixels = gdk_pixbuf_get_pixels (pixbuf);
-              width = gdk_pixbuf_get_width (pixbuf);
-              height = gdk_pixbuf_get_height (pixbuf);
-              rowstride = gdk_pixbuf_get_rowstride (pixbuf);
-              for (x = 0; x < width; x++)
-                for (y = 0; y < height; y++)
-                  if (pixels[y * rowstride + x * 4 + 3] > 0)
-                    goto loop_left;
-              loop_left: left = x;
-              for (y = 0; y < height; y++)
-                for (x = 0; x < width; x++)
-                  if (pixels[y * rowstride + x * 4 + 3] > 0)
-                    goto loop_top;
-              loop_top: top = y;
-              for (x = width - 1; x >= 0; x--)
-                for (y = 0; y < height; y++)
-                  if (pixels[y * rowstride + x * 4 + 3] > 0)
-                    goto loop_right;
-              loop_right: right = x;
-              for (y = height - 1; y >= 0; y--)
-                for (x = 0; x < width; x++)
-                  if (pixels[y * rowstride + x * 4 + 3] > 0)
-                    goto loop_bottom;
-              loop_bottom: bottom = y;
-              if (left <= right && top <= bottom)
-                {
-                  int w, h, r;
-                  guchar *p;
-                  gint i;
-                  GdkPixbuf *b;
-
-                  w = right - left + 1;
-                  h = bottom - top + 1;
-                  b = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, w, h);
-                  p = gdk_pixbuf_get_pixels (b);
-                  r = gdk_pixbuf_get_rowstride (b);
-                  for (x = 0; x < w; x++)
-                    for (y = 0; y < h; y++)
-                      for (i = 0; i < 4; i++)
-                        p[y * r + x * 4 + i]
-                        = pixels[(y + top) * rowstride + (x + left) * 4 + i];
-                  image = gtk_image_new_from_pixbuf (b);
-                  g_object_unref (b);
-                }
-            }
-          g_object_unref (pixbuf);
-        }
-    }
-  if (!image)
-    image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
-  if (!image)
-    {
-      const static gchar *xpm[] = {
-"12 13 4 1",
-"   c None",
-"X  c #000000",
-"+  c #808080",
-".  c #FFFFFF",
-"+++++++++++.",
-"+.........+.",
-"+.        +.",
-"+.XX    XX+.",
-"+. XX  XX +.",
-"+.  XXXX  +.",
-"+.   XX   +.",
-"+.  XXXX  +.",
-"+. XX  XX +.",
-"+.XX    XX+.",
-"+.        +.",
-"+++++++++++.",
-"............"};
-
-      pixbuf = gdk_pixbuf_new_from_xpm_data (xpm);
-      image = gtk_image_new_from_pixbuf (pixbuf);
-      g_object_unref (pixbuf);
-    }
   /* ja:ボタン */
-  button = gtk_button_new ();
-  gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
-  gtk_container_add (GTK_CONTAINER (button), image);
-  gtk_widget_show_all (button);
+  button = misc_close_button ();
+  gtk_widget_show (button);
   /* ja:ラベル */
   tab->label = gtk_label_new ("");
   orz_mdi_label_markup (tab);
@@ -703,9 +580,11 @@ orz_mdi_create_tab_label (OrzMdi         *mdi,
   g_object_set_data (G_OBJECT (event), "user_data", tab);
 
   g_signal_connect (G_OBJECT (button), "clicked",
-                                        G_CALLBACK (orz_mdi_clicked), event);
+                                    G_CALLBACK (orz_mdi_clicked), event);
   g_signal_connect (G_OBJECT (child), "destroy",
-                                        G_CALLBACK (orz_mdi_destroy), mdi);
+                                    G_CALLBACK (orz_mdi_destroy_child), mdi);
+  g_signal_connect (G_OBJECT (event), "destroy",
+                                    G_CALLBACK (orz_mdi_destroy_tab), mdi);
   /* en:Drag & Drop */
   gtk_drag_source_set (event, GDK_BUTTON1_MASK, dnd_entries, 1,
                                                             GDK_ACTION_MOVE);
@@ -925,8 +804,8 @@ orz_mdi_get_tab (OrzMdi     *mdi,
           GtkWidget *tab_label;
 
           tab_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (mdi), child);
-          if (tab_label)
-            return g_object_get_data (G_OBJECT (tab_label), "user_data");
+          if (tab_label){
+            return g_object_get_data (G_OBJECT (tab_label), "user_data");}
         }
     }
   return NULL;
