@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -132,7 +132,7 @@ version_dialog (void)
   const static gchar *str[3] = {N_("Name"), N_("Code"), N_("Attribute")};
   const static gchar *authors =
 "Supreme Programmer:\n"
-" Kazuki IWAMOTO <iwm@maid.org>\n"
+" Kazuki Iwamoto <iwm@maid.org>\n"
 "\n"
 "Codecs Author:\n"
 " ryoma <ryoma@users.sourceforge.jp>\n"
@@ -224,62 +224,55 @@ version_dialog (void)
                                             4, NULL,
                                             -1);
   glist = icm_get_handler_list ();
-  if (glist)
+  for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
     {
-      gint length;
+      IcmObject *icm_object;
 
-      length = g_list_length (glist);
-      for (i = 0; i < length; i++)
+      icm_object = icm_open (GPOINTER_TO_UINT (glist->data), ICM_MODE_QUERY);
+      if (icm_object)
         {
-          IcmObject *icm_object;
+          gchar *handler;
+          const gchar *name, *attribute;
 
-          icm_object = icm_open (GPOINTER_TO_UINT (g_list_nth_data (glist, i)),
-                                                            ICM_MODE_QUERY);
-          if (icm_object)
+          name = icm_get_name (icm_object);
+          handler = icm_handler_to_string (icm_get_handler (icm_object));
+          switch (icm_get_attribute (icm_object))
             {
-              gchar *handler;
-              const gchar *name, *attribute;
-
-              name = icm_get_name (icm_object);
-              handler = icm_handler_to_string (icm_get_handler (icm_object));
-              switch (icm_get_attribute (icm_object))
-                {
-                  case ICM_ATTR_NATIVE:
-                    attribute = _("Video maid Native");
-                    break;
-                  case ICM_ATTR_WIN32:
+              case ICM_ATTR_NATIVE:
+                attribute = _("Video maid Native");
+                break;
+              case ICM_ATTR_WIN32:
 #ifdef G_OS_WIN32
-                    attribute = _("Win32 Native");
+                attribute = _("Win32 Native");
 #else /* not G_OS_WIN32 */
-                    attribute = _("Win32 Emulation");
+                attribute = _("Win32 Emulation");
 #endif /* not G_OS_WIN32 */
-                    break;
-                  default:
-                    attribute = _("Unknown");
-                }
-              if (name && handler)
-                {
-                  GtkTreeIter iter;
+                break;
+              default:
+                attribute = _("Unknown");
+            }
+          if (name && handler)
+            {
+              GtkTreeIter iter;
 
-                  gtk_tree_store_append (store, &iter, &iter_parent);
-                  gtk_tree_store_set (store, &iter, 0, name,
+              gtk_tree_store_append (store, &iter, &iter_parent);
+              gtk_tree_store_set (store, &iter, 0, name,
                                                     1, handler,
                                                     2, attribute,
                                                     3, NULL,
                                                     4, NULL,
                                                     -1);
-                  if (icm_is_dialog_about (icm_object))
-                    {
-                      gtk_tree_store_set (store, &iter, 3, icm_object, -1);
-                      icm_object = NULL;
-                    }
+              if (icm_is_dialog_about (icm_object))
+                {
+                  gtk_tree_store_set (store, &iter, 3, icm_object, -1);
+                  icm_object = NULL;
                 }
-              g_free (handler);
-              if (icm_object)
-                icm_close (icm_object);
             }
+          g_free (handler);
+          if (icm_object)
+            icm_close (icm_object);
         }
-      g_list_free (glist);
     }
   gtk_tree_store_append (store, &iter_parent, NULL);
   gtk_tree_store_set (store, &iter_parent,  0, _("Audio Compressor"),
@@ -289,62 +282,55 @@ version_dialog (void)
                                             4, NULL,
                                             -1);
   glist = acm_get_tag_list ();
-  if (glist)
+  for (glist = g_list_first (glist);
+                            glist; glist = g_list_delete_link (glist, glist))
     {
-      gint length;
+      AcmObject *acm_object;
 
-      length = g_list_length (glist);
-      for (i = 0; i < length; i++)
+      acm_object = acm_open ((guint16)GPOINTER_TO_UINT (glist->data));
+      if (acm_object)
         {
-          AcmObject *acm_object;
+          gchar *handler;
+          const gchar *name, *attribute;
 
-          acm_object = acm_open
-                    ((guint16)GPOINTER_TO_UINT (g_list_nth_data (glist, i)));
-          if (acm_object)
+          name = acm_get_name (acm_object);
+          handler = g_strdup_printf ("%04X", acm_get_tag (acm_object));
+          switch (acm_get_attribute (acm_object))
             {
-              gchar *handler;
-              const gchar *name, *attribute;
-
-              name = acm_get_name (acm_object);
-              handler = g_strdup_printf ("%04X", acm_get_tag (acm_object));
-              switch (acm_get_attribute (acm_object))
-                {
-                  case ACM_ATTR_NATIVE:
-                    attribute = _("Video maid Native");
-                    break;
-                  case ACM_ATTR_WIN32:
+              case ACM_ATTR_NATIVE:
+                attribute = _("Video maid Native");
+                break;
+              case ACM_ATTR_WIN32:
 #ifdef G_OS_WIN32
-                    attribute = _("Win32 Native");
+                attribute = _("Win32 Native");
 #else /* not G_OS_WIN32 */
-                    attribute = _("Win32 Emulation");
+                attribute = _("Win32 Emulation");
 #endif /* not G_OS_WIN32 */
-                    break;
-                  default:
-                    attribute = _("Unknown");
-                }
-              if (name && handler)
-                {
-                  GtkTreeIter iter;
+                break;
+              default:
+                attribute = _("Unknown");
+            }
+          if (name && handler)
+            {
+              GtkTreeIter iter;
 
-                  gtk_tree_store_append (store, &iter, &iter_parent);
-                  gtk_tree_store_set (store, &iter, 0, name,
+              gtk_tree_store_append (store, &iter, &iter_parent);
+              gtk_tree_store_set (store, &iter, 0, name,
                                                     1, handler,
                                                     2, attribute,
                                                     3, NULL,
                                                     4, NULL,
                                                     -1);
-                  if (acm_is_dialog_about (acm_object))
-                    {
-                      gtk_tree_store_set (store, &iter, 4, acm_object, -1);
-                      acm_object = NULL;
-                    }
+              if (acm_is_dialog_about (acm_object))
+                {
+                  gtk_tree_store_set (store, &iter, 4, acm_object, -1);
+                  acm_object = NULL;
                 }
-              g_free (handler);
-              if (acm_object)
-                acm_close (acm_object);
             }
+          g_free (handler);
+          if (acm_object)
+            acm_close (acm_object);
         }
-      g_list_free (glist);
     }
   tview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
   gtk_tree_view_set_enable_search (GTK_TREE_VIEW (tview), FALSE);
