@@ -1,6 +1,6 @@
 /*
     w32loader
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2009 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,9 +32,38 @@ G_BEGIN_DECLS
 #define IMAGE_NT_SIGNATURE  0x00004550
 
 
+/* ja:MS-DOSヘッダ */
+typedef struct _IMAGE_DOS_HEADER
+{
+  WORD e_magic;
+  WORD e_cblp;
+  WORD e_cp;
+  WORD e_crlc;
+  WORD e_cparhdr;
+  WORD e_minalloc;
+  WORD e_maxalloc;
+  WORD e_ss;
+  WORD e_sp;
+  WORD e_csum;
+  WORD e_ip;
+  WORD e_cs;
+  WORD e_lfarlc;
+  WORD e_ovno;
+  WORD e_res[4];
+  WORD e_oemid;
+  WORD e_oeminfo;
+  WORD e_res2[10];
+  LONG e_lfanew;
+} IMAGE_DOS_HEADER, *PIMAGE_DOS_HEADER;
+
+
 /* ja:ファイルヘッダ */
 #define IMAGE_FILE_MACHINE_I386 0x014c
-#define IMAGE_FILE_DLL 0x2000
+#define IMAGE_FILE_EXECUTABLE_IMAGE    0x0002
+#define IMAGE_FILE_LINE_NUMS_STRIPPED  0x0004
+#define IMAGE_FILE_LOCAL_SYMS_STRIPPED 0x0008
+#define IMAGE_FILE_32BIT_MACHINE       0x0100
+#define IMAGE_FILE_DLL                 0x2000
 typedef struct _IMAGE_FILE_HEADER
 {
   WORD Machine;
@@ -58,6 +87,12 @@ typedef struct _IMAGE_DATA_DIRECTORY
   DWORD Size;
 } IMAGE_DATA_DIRECTORY, *PIMAGE_DATA_DIRECTORY;
 #define IMAGE_NT_OPTIONAL_HDR_MAGIC 0x10b
+#define IMAGE_SUBSYSTEM_UNKNOWN        0
+#define IMAGE_SUBSYSTEM_NATIVE         1
+#define IMAGE_SUBSYSTEM_WINDOWS_GUI    2
+#define IMAGE_SUBSYSTEM_WINDOWS_CUI    3
+#define IMAGE_SUBSYSTEM_POSIX_CUI      7
+#define IMAGE_SUBSYSTEM_WINDOWS_CE_GUI 9
 #define IMAGE_NUMBEROF_DIRECTORY_ENTRIES 16
 typedef struct _IMAGE_OPTIONAL_HEADER
 {
@@ -97,6 +132,17 @@ typedef struct _IMAGE_OPTIONAL_HEADER
 
 /* ja:セクションヘッダ */
 #define IMAGE_SIZEOF_SHORT_NAME 8
+#define IMAGE_SCN_CNT_CODE               0x00000020
+#define IMAGE_SCN_CNT_INITIALIZED_DATA   0x00000040
+#define IMAGE_SCN_CNT_UNINITIALIZED_DATA 0x00000080
+#define IMAGE_SCN_LNK_OVFL               0x01000000
+#define IMAGE_SCN_MEM_DISCARDABLE        0x02000000
+#define IMAGE_SCN_MEM_NOT_CACHED         0x04000000
+#define IMAGE_SCN_MEM_NOT_PAGED          0x08000000
+#define IMAGE_SCN_MEM_SHARED             0x10000000
+#define IMAGE_SCN_MEM_EXECUTE            0x20000000
+#define IMAGE_SCN_MEM_READ               0x40000000
+#define IMAGE_SCN_MEM_WRITE              0x80000000
 typedef struct _IMAGE_SECTION_HEADER
 {
   BYTE Name[IMAGE_SIZEOF_SHORT_NAME];
