@@ -1,10 +1,10 @@
 /*
     w32loader
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #ifndef __OLEAUT32_H__
 #define __OLEAUT32_H__
@@ -23,9 +22,7 @@
 #include "w32ldr.h"
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 
 #include "ole32.h"
@@ -38,7 +35,7 @@ typedef enum _REGKIND
 } REGKIND;
 
 
-extern W32LdrExport oleaut32_exports[];
+extern W32LdrExport w32ldr_oleaut32_exports[];
 
 
 HRESULT WINAPI LoadTypeLib (LPCOLESTR szFile, ITypeLib **pptLib);
@@ -46,9 +43,7 @@ HRESULT WINAPI LoadTypeLibEx (LPCOLESTR szFile, REGKIND regkind, ITypeLib **pptL
 HRESULT WINAPI RegisterTypeLib (ITypeLib *ptlib, OLECHAR *szFullPath, OLECHAR *szHelpDir);
 
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 
 #endif /* __OLEAUT32_H__ */
