@@ -1,6 +1,6 @@
 /*
     w32loader
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -954,7 +954,7 @@ typedef CONST DLGITEMTEMPLATEEX *PCDLGITEMTEMPLATEEX, *LPCDLGITEMTEMPLATEEX;
 #define IDCONTINUE 11
 
 
-extern W32LdrExport user32_exports[];
+extern W32LdrExport w32ldr_user32_exports[];
 
 
 BOOL WINAPI AppendMenuA (HMENU hMenu, UINT uFlags, UINT_PTR uItem, LPCSTR lpszItem);
