@@ -1,10 +1,10 @@
 /*
     w32loader
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "version.h"
 #include "kernel32.h"
@@ -122,19 +121,19 @@ BOOL WINAPI VerQueryValueW (LPCVOID pBlock, LPWSTR lpSubBlock, LPVOID *lplpBuffe
 }
 
 
-W32LdrExport version_exports[] = {
-{TRUE,   1, "GetFileVersionInfoA",     GetFileVersionInfoA},
-{TRUE,   2, "GetFileVersionInfoSizeA", GetFileVersionInfoSizeA},
-{TRUE,   3, "GetFileVersionInfoSizeW", GetFileVersionInfoSizeW},
-{TRUE,   4, "GetFileVersionInfoW",     GetFileVersionInfoW},
-{FALSE,  5, "VerFindFileA",            VerFindFileA},
-{FALSE,  6, "VerFindFileW",            VerFindFileW},
-{FALSE,  7, "VerInstallFileA",         VerInstallFileA},
-{FALSE,  8, "VerInstallFileW",         VerInstallFileW},
-{FALSE,  9, "VerLanguageNameA",        version_VerLanguageNameA},
-{FALSE, 10, "VerLanguageNameW",        version_VerLanguageNameW},
-{TRUE,  11, "VerQueryValueA",          VerQueryValueA},
-{FALSE, 12, "VerQueryValueIndexA",     VerQueryValueIndexA},
-{FALSE, 13, "VerQueryValueIndexW",     VerQueryValueIndexW},
-{TRUE,  14, "VerQueryValueW",          VerQueryValueW},
-{FALSE,  0, NULL,                      NULL}};
+W32LdrExport w32ldr_version_exports[] = {
+{ 0,  1, "GetFileVersionInfoA",     GetFileVersionInfoA},
+{ 0,  2, "GetFileVersionInfoSizeA", GetFileVersionInfoSizeA},
+{ 0,  3, "GetFileVersionInfoSizeW", GetFileVersionInfoSizeW},
+{ 0,  4, "GetFileVersionInfoW",     GetFileVersionInfoW},
+{-1,  5, "VerFindFileA",            VerFindFileA},
+{-1,  6, "VerFindFileW",            VerFindFileW},
+{-1,  7, "VerInstallFileA",         VerInstallFileA},
+{-1,  8, "VerInstallFileW",         VerInstallFileW},
+{-1,  9, "VerLanguageNameA",        version_VerLanguageNameA},
+{-1, 10, "VerLanguageNameW",        version_VerLanguageNameW},
+{ 0, 11, "VerQueryValueA",          VerQueryValueA},
+{-1, 12, "VerQueryValueIndexA",     VerQueryValueIndexA},
+{-1, 13, "VerQueryValueIndexW",     VerQueryValueIndexW},
+{ 0, 14, "VerQueryValueW",          VerQueryValueW},
+{-1,  0, NULL,                      NULL}};
