@@ -22,7 +22,9 @@
 #include <gdk/gdkkeysyms.h>
 
 
-#define MAX_COLUMN 32
+#define MAX_COLUMN     32
+#define LVIEW_LPARAM   MAX_COLUMN
+#define LVIEW_EDITABLE (MAX_COLUMN+1)
 
 
 static LRESULT WINAPI
@@ -72,7 +74,7 @@ w32lview_DefWindowProc (HWND   hWnd,
 
                 lResult = TRUE;
                 gtk_tree_model_get (model, &iter, lvi->iSubItem, &utf8str,
-                                                    MAX_COLUMN, &param, -1);
+                                                    LVIEW_LPARAM, &param, -1);
                 if (lvi->mask & LVIF_STATE)
                   {
                     GtkTreeSelection *select;
@@ -132,7 +134,7 @@ w32lview_DefWindowProc (HWND   hWnd,
 
                 lResult = TRUE;
                 gtk_tree_model_get (model, &iter, lvi->iSubItem, &utf8str,
-                                                    MAX_COLUMN, &param, -1);
+                                                    LVIEW_LPARAM, &param, -1);
                 if (lvi->mask & LVIF_STATE)
                   {
                     GtkTreeSelection *select;
@@ -220,7 +222,7 @@ w32lview_DefWindowProc (HWND   hWnd,
                   lResult = FALSE;
                 if (lvi->mask & LVIF_PARAM)
                   gtk_list_store_set (store, &iter,
-                                                MAX_COLUMN, lvi->lParam, -1);
+                                                LVIEW_LPARAM, lvi->lParam, -1);
               }
             return lResult;
           }
@@ -270,7 +272,7 @@ w32lview_DefWindowProc (HWND   hWnd,
                   lResult = FALSE;
                 if (lvi->mask & LVIF_PARAM)
                   gtk_list_store_set (store, &iter,
-                                                MAX_COLUMN, lvi->lParam, -1);
+                                                LVIEW_LPARAM, lvi->lParam, -1);
               }
             return lResult;
           }
@@ -286,6 +288,8 @@ w32lview_DefWindowProc (HWND   hWnd,
             store = GTK_LIST_STORE (gtk_tree_view_get_model
                                                     (GTK_TREE_VIEW (lview)));
             gtk_list_store_insert (store, &iter, lvi->iItem);
+            gtk_list_store_set (store, &iter,
+                            LVIEW_EDITABLE, wd->dwStyle & LVS_EDITLABELS, -1);
             if (lvi->mask & LVIF_STATE && lvi->stateMask & LVIS_SELECTED)
               {
                 GtkTreeSelection *select;
@@ -305,7 +309,7 @@ w32lview_DefWindowProc (HWND   hWnd,
                 g_free (utf8str);
               }
             if (lvi->mask & LVIF_PARAM)
-              gtk_list_store_set (store, &iter, MAX_COLUMN, lvi->lParam, -1);
+              gtk_list_store_set (store, &iter, LVIEW_LPARAM, lvi->lParam, -1);
             return lvi->iItem;
           }
         return -1;
@@ -320,6 +324,8 @@ w32lview_DefWindowProc (HWND   hWnd,
             store = GTK_LIST_STORE (gtk_tree_view_get_model
                                                     (GTK_TREE_VIEW (lview)));
             gtk_list_store_insert (store, &iter, lvi->iItem);
+            gtk_list_store_set (store, &iter,
+                            LVIEW_EDITABLE, wd->dwStyle & LVS_EDITLABELS, -1);
             if (lvi->mask & LVIF_STATE && lvi->stateMask & LVIS_SELECTED)
               {
                 GtkTreeSelection *select;
@@ -340,7 +346,7 @@ w32lview_DefWindowProc (HWND   hWnd,
                 g_free (utf8str);
               }
             if (lvi->mask & LVIF_PARAM)
-              gtk_list_store_set (store, &iter, MAX_COLUMN, lvi->lParam, -1);
+              gtk_list_store_set (store, &iter, LVIEW_LPARAM, lvi->lParam, -1);
             return lvi->iItem;
           }
         return -1;
@@ -443,7 +449,7 @@ w32lview_DefWindowProc (HWND   hWnd,
                     gint result, param_tmp;
 
                     gtk_tree_model_get (model, &iter, 0, &utf8str_tmp,
-                                                MAX_COLUMN, &param_tmp, -1);
+                                                LVIEW_LPARAM, &param_tmp, -1);
                     result = flags & LVFI_PARAM ? param - param_tmp
                         : flags & LVFI_STRING ? g_strcmp (utf8str, utf8str_tmp)
                         : flags & LVFI_PARTIAL ? g_strncmp (utf8str,
@@ -468,7 +474,7 @@ w32lview_DefWindowProc (HWND   hWnd,
                       gint result, param_tmp;
 
                       gtk_tree_model_get (model, &iter, 0, &utf8str_tmp,
-                                                MAX_COLUMN, &param_tmp, -1);
+                                                LVIEW_LPARAM, &param_tmp, -1);
                       result = flags & LVFI_PARAM ? param - param_tmp
                         : flags & LVFI_STRING ? g_strcmp (utf8str, utf8str_tmp)
                         : flags & LVFI_PARTIAL ? g_strncmp (utf8str,
@@ -545,13 +551,14 @@ w32lview_DefWindowProc (HWND   hWnd,
             gint width;
             PangoLayout *layout;
 
-            utf8str = Msg == LVM_GETSTRINGWIDTHW
-                            ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam), -1,
+            utf8str = lParam ? Msg == LVM_GETSTRINGWIDTHW
+                             ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam), -1,
                                                             NULL, NULL, NULL)
-                            : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam));
+                             : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam))
+                             : g_strdup ("");
             layout = gtk_widget_create_pango_layout (lview, utf8str);
             pango_layout_get_pixel_size (layout, &width, NULL);
-            g_object_unref (layout);
+            g_object_unref (G_OBJECT (layout));
             g_free (utf8str);
             return width;
           }
@@ -833,8 +840,8 @@ w32lview_DefWindowProc (HWND   hWnd,
               }
             renderer = gtk_cell_renderer_text_new ();
             column = gtk_tree_view_column_new_with_attributes
-                            (utf8str, renderer, "text", wParam * 2,
-                            "editable", wd->dwStyle & LVS_EDITLABELS, NULL);
+                                        (utf8str, renderer, "text", wParam * 2,
+                                            "editable", LVIEW_EDITABLE, NULL);
             g_free (utf8str);
             gtk_tree_view_column_set_alignment (column, xalign);
             gtk_tree_view_insert_column (GTK_TREE_VIEW (lview),
@@ -1044,7 +1051,7 @@ w32lview_DefWindowProc (HWND   hWnd,
                                                             &iter1, NULL, 0))
                   return FALSE;
                 gtk_tree_model_get (GTK_TREE_MODEL (store), &iter1,
-                                                    MAX_COLUMN, &lParam1, -1);
+                                                LVIEW_LPARAM, &lParam1, -1);
                 for (j = 1; j <= i; j++)
                   {
                     GtkTreeIter iter2;
@@ -1054,7 +1061,7 @@ w32lview_DefWindowProc (HWND   hWnd,
                                                             &iter2, NULL, j))
                       return FALSE;
                     gtk_tree_model_get (GTK_TREE_MODEL (store), &iter2,
-                                                    MAX_COLUMN, &lParam2, -1);
+                                                LVIEW_LPARAM, &lParam2, -1);
                     if (CompareFunc (lParam1, lParam2, wParam) > 0)
                       {
                         gtk_list_store_swap (store, &iter1, &iter2);
@@ -1127,12 +1134,14 @@ w32lview_row_changed (GtkTreeModel *model,
   if (indices)
     {
       GtkTreeSelection *select;
+      GtkWidget *parent;
       W32LdrWindowData *wd;
       NM_LISTVIEW nml;
 
       select = gtk_tree_view_get_selection (GTK_TREE_VIEW (widget));
-      wd = g_object_get_data (G_OBJECT (widget), "user_data");
-      nml.hdr.hwndFrom = widget;
+      parent = gtk_widget_get_parent (widget);
+      wd = g_object_get_data (G_OBJECT (parent), "user_data");
+      nml.hdr.hwndFrom = parent;
       nml.hdr.idFrom = wd->wID;
       nml.hdr.code = LVN_ITEMCHANGING;
       nml.iItem = indices[0];
@@ -1143,7 +1152,7 @@ w32lview_row_changed (GtkTreeModel *model,
       nml.uChanged = 0;
       nml.ptAction.x = 0;
       nml.ptAction.y = 0;
-      gtk_tree_model_get (model, iter, MAX_COLUMN, &nml.lParam, -1);
+      gtk_tree_model_get (model, iter, LVIEW_LPARAM, &nml.lParam, -1);
       if (wd->widechar)
         SendMessageW (wd->hWndParent, WM_NOTIFY,
                                             wd->wID, GPOINTER_TO_INT (&nml));
@@ -1166,11 +1175,13 @@ w32lview_row_deleted (GtkTreeModel *model,
                       GtkTreePath  *path,
                       GtkWidget    *widget)
 {
+  GtkWidget *parent;
   W32LdrWindowData *wd;
   NM_LISTVIEW nml;
 
-  wd = g_object_get_data (G_OBJECT (widget), "user_data");
-  nml.hdr.hwndFrom = widget;
+  parent = gtk_widget_get_parent (widget);
+  wd = g_object_get_data (G_OBJECT (parent), "user_data");
+  nml.hdr.hwndFrom = parent;
   nml.hdr.idFrom = wd->wID;
   nml.hdr.code = LVN_DELETEITEM;
   nml.iItem = -1;
@@ -1199,11 +1210,13 @@ w32lview_row_inserted (GtkTreeModel *model,
   indices = gtk_tree_path_get_indices (path);
   if (indices)
     {
+      GtkWidget *parent;
       W32LdrWindowData *wd;
       NM_LISTVIEW nml;
 
-      wd = g_object_get_data (G_OBJECT (widget), "user_data");
-      nml.hdr.hwndFrom = widget;
+      parent = gtk_widget_get_parent (widget);
+      wd = g_object_get_data (G_OBJECT (parent), "user_data");
+      nml.hdr.hwndFrom = parent;
       nml.hdr.idFrom = wd->wID;
       nml.hdr.code = LVN_INSERTITEM;
       nml.iItem = indices[0];
@@ -1230,11 +1243,13 @@ w32lview_clicked (GtkTreeViewColumn *column,
                   GtkWidget         *widget)
 {
   GList *glist;
+  GtkWidget *parent;
   W32LdrWindowData *wd;
   NM_LISTVIEW nml;
 
-  wd = g_object_get_data (G_OBJECT (widget), "user_data");
-  nml.hdr.hwndFrom = widget;
+  parent = gtk_widget_get_parent (widget);
+  wd = g_object_get_data (G_OBJECT (parent), "user_data");
+  nml.hdr.hwndFrom = parent;
   nml.hdr.idFrom = wd->wID;
   nml.hdr.code = LVN_COLUMNCLICK;
   nml.iItem = -1;
@@ -1262,6 +1277,7 @@ w32lview_button_press_event (GtkWidget      *widget,
                              GdkEventButton *event,
                              gpointer        user_data)
 {
+  GtkWidget *parent;
   W32LdrWindowData *wd;
   NMHDR nmh;
 
@@ -1285,8 +1301,9 @@ w32lview_button_press_event (GtkWidget      *widget,
         break;
       default: return FALSE;
     }
-  wd = g_object_get_data (G_OBJECT (widget), "user_data");
-  nmh.hwndFrom = widget;
+  parent = gtk_widget_get_parent (widget);
+  wd = g_object_get_data (G_OBJECT (parent), "user_data");
+  nmh.hwndFrom = parent;
   nmh.idFrom = wd->wID;
   if (wd->widechar)
     SendMessageW (wd->hWndParent, WM_NOTIFY, wd->wID, GPOINTER_TO_INT (&nmh));
@@ -1302,11 +1319,13 @@ w32lview_focus_in (GtkWidget     *widget,
                    GdkEventFocus *event,
                    gpointer       user_data)
 {
+  GtkWidget *parent;
   W32LdrWindowData *wd;
   NMHDR nmh;
 
-  wd = g_object_get_data (G_OBJECT (widget), "user_data");
-  nmh.hwndFrom = widget;
+  parent = gtk_widget_get_parent (widget);
+  wd = g_object_get_data (G_OBJECT (parent), "user_data");
+  nmh.hwndFrom = parent;
   nmh.idFrom = wd->wID;
   nmh.code = NM_SETFOCUS;
   if (wd->widechar)
@@ -1323,11 +1342,13 @@ w32lview_focus_out (GtkWidget     *widget,
                     GdkEventFocus *event,
                     gpointer       user_data)
 {
+  GtkWidget *parent;
   W32LdrWindowData *wd;
   NMHDR nmh;
 
-  wd = g_object_get_data (G_OBJECT (widget), "user_data");
-  nmh.hwndFrom = widget;
+  parent = gtk_widget_get_parent (widget);
+  wd = g_object_get_data (G_OBJECT (parent), "user_data");
+  nmh.hwndFrom = parent;
   nmh.idFrom = wd->wID;
   nmh.code = NM_KILLFOCUS;
   if (wd->widechar)
@@ -1346,11 +1367,13 @@ w32lview_key_press_event (GtkWidget   *widget,
 {
   if (event->keyval == GDK_Return)
     {
+      GtkWidget *parent;
       W32LdrWindowData *wd;
       NMHDR nmh;
 
-      wd = g_object_get_data (G_OBJECT (widget), "user_data");
-      nmh.hwndFrom = widget;
+      parent = gtk_widget_get_parent (widget);
+      wd = g_object_get_data (G_OBJECT (parent), "user_data");
+      nmh.hwndFrom = parent;
       nmh.idFrom = wd->wID;
       nmh.code = NM_RETURN;
       if (wd->widechar)
@@ -1376,7 +1399,7 @@ w32ldr_control_create_lview (const gchar    *windowname,
                              const gboolean  widechar)
 {
   gint i;
-  GType types[MAX_COLUMN + 1];
+  GType types[MAX_COLUMN + 2];
   GtkCellRenderer *renderer;
   GtkListStore *store;
   GtkTreeSelection *select;
@@ -1387,7 +1410,8 @@ w32ldr_control_create_lview (const gchar    *windowname,
   /* ja:リストビュー */
   for (i = 0; i < MAX_COLUMN; i++)
     types[i] = G_TYPE_STRING;
-  types[MAX_COLUMN] = G_TYPE_INT;
+  types[LVIEW_LPARAM] = G_TYPE_INT;
+  types[LVIEW_EDITABLE] = G_TYPE_BOOLEAN;
   store = gtk_list_store_newv (G_N_ELEMENTS (types), types);
   lview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (lview),
@@ -1395,8 +1419,8 @@ w32ldr_control_create_lview (const gchar    *windowname,
   gtk_tree_view_set_enable_search (GTK_TREE_VIEW (lview),
                                                 !(style & LVS_NOSORTHEADER));
   renderer = gtk_cell_renderer_text_new ();
-  column = gtk_tree_view_column_new_with_attributes
-        (NULL, renderer, "text", 0, "editable", style & LVS_EDITLABELS, NULL);
+  column = gtk_tree_view_column_new_with_attributes (NULL, renderer,
+                                "text", 0, "editable", LVIEW_EDITABLE, NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (lview), column);
   select = gtk_tree_view_get_selection (GTK_TREE_VIEW (lview));
   gtk_tree_selection_set_mode (select,
@@ -1419,7 +1443,8 @@ w32ldr_control_create_lview (const gchar    *windowname,
                             G_CALLBACK (w32lview_key_press_event), NULL);
   gtk_widget_add_events (lview, GDK_BUTTON_PRESS_MASK | GDK_FOCUS_CHANGE_MASK
                                                         | GDK_KEY_PRESS_MASK);
-  g_object_unref (store);
+  g_object_unref (G_OBJECT (store));
+  gtk_widget_show (lview);
   /* ja:スクロールウインドウ */
   scroll = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
