@@ -1,10 +1,10 @@
 /*
     w32loader
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "w32private.h"
 #include "commctrl.h"
@@ -489,6 +488,8 @@ w32ldr_control_create_prsht (const gchar    *windowname,
       vbox = gtk_vbox_new (FALSE, SPACING);
       gtk_widget_show (vbox);
       gtk_container_add (GTK_CONTAINER (prsht), vbox);
+      gtk_window_set_position (GTK_WINDOW (prsht),
+                                                GTK_WIN_POS_CENTER_ON_PARENT);
     }
   else
     {
@@ -593,7 +594,6 @@ w32ldr_control_create_prsht (const gchar    *windowname,
   gtk_box_pack_start (GTK_BOX (vbox), notebook, TRUE, TRUE, 0);
   gtk_box_pack_end (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   gtk_window_set_destroy_with_parent (GTK_WINDOW (prsht), TRUE);
-  gtk_window_set_position (GTK_WINDOW (prsht), GTK_WIN_POS_CENTER_ON_PARENT);
   nd = g_malloc (sizeof (W32LdrNoteData));
   wd = &nd->wd;
   wd->dwStyle = style;
