@@ -133,7 +133,7 @@ typedef CONST FILETIME *PCFILETIME, *LPCFILETIME;
 #define RT_ANICURSOR    21
 #define RT_ANIICON      22
 #define RT_HTML         23
-typedef LPVOID HRSRC;
+typedef LPCVOID HRSRC;
 #define IS_INTRESOURCE(x)   ((GPOINTER_TO_UINT(x)>>16)==0)
 #define MAKEINTRESOURCEA(i) (LPSTR)(GUINT_TO_POINTER((DWORD)(WORD)(i)))
 #define MAKEINTRESOURCEW(i) (LPWSTR)(GUINT_TO_POINTER((DWORD)(WORD)(i)))
